-----------------------------------------------------------------------------------------------
-- Client Lua Script for SpiralDecorCalculator
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
require "Window"
 
-----------------------------------------------------------------------------------------------
-- SpiralDecorCalculator Module Definition
-----------------------------------------------------------------------------------------------
local SpiralDecorCalculator = {} 
y_val_start = 0
y_val_stop = 0
x_val_center = 0
z_val_center = 0
n_steps = 1
rotation_val_degree = 0
radius_val = 1
rotation_val_start = 0
clockwise = 0
propx = {n=32}
propy = {n=32}
propz = {n=32}
proppitch = 0
proproll = {n=32}
propyaw = 0 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
local kcrSelectedText = ApolloColor.new("UI_BtnTextHoloPressedFlyby")
local kcrNormalText = ApolloColor.new("UI_BtnTextHoloNormal")
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function SpiralDecorCalculator:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
	o.tItems = {} -- keep track of all the list items
	o.wndSelectedListItem = nil -- keep track of which list item is currently selected

    return o
end

function SpiralDecorCalculator:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end


-----------------------------------------------------------------------------------------------
-- SpiralDecorCalculator OnLoad
-----------------------------------------------------------------------------------------------
function SpiralDecorCalculator:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("SpiralDecorCalculator.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- SpiralDecorCalculator OnDocLoaded
-----------------------------------------------------------------------------------------------
function SpiralDecorCalculator:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "SpiralDecorCalculatorForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
		-- item list
		self.wndItemList = self.wndMain:FindChild("ItemList")
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("spiral", "OnSpiralDecorCalculatorOn", self)

		self.timer = ApolloTimer.Create(1.0, true, "OnTimer", self)

		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- SpiralDecorCalculator Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/SSH"
function SpiralDecorCalculator:OnSpiralDecorCalculatorOn()
	local drPlayer = GameLib.GetPlayerUnit()
	local strName = drPlayer and drPlayer:GetName() or "Player"
	self.wndMain:Invoke() -- show the window
	Print("Welcome " .. strName)
end

-- on timer
function SpiralDecorCalculator:OnTimer()
	-- Do your timer-related stuff here.
end


-----------------------------------------------------------------------------------------------
-- SpiralDecorCalculatorForm Functions
-----------------------------------------------------------------------------------------------



-- when the calculate button is clicked
function SpiralDecorCalculator:OnOK()
if y_val_start and y_val_stop and n_steps then
	Print("Calculation Succesfull")
	Print("Select the decor you want to move and push the according step number in the right menu")
	for step=1,n_steps do
	
		-- roll
		if clockwise == 1 then
			proproll[step] = rotation_val_start-(rotation_val_degree*(1/(n_steps-1))*(step-1))
		elseif clockwise == 0 then
			proproll[step] = rotation_val_start+(rotation_val_degree*(1/(n_steps-1))*(step-1))
		end
		-- x
		propx[step] = x_val_center-radius_val*math.sin(math.rad(proproll[step]+90))
				
		-- y
		propy[step] = y_val_start + (y_val_stop-y_val_start)*(1/(n_steps-1))*(step-1)
				
		-- z
		propz[step] = z_val_center-radius_val*math.sin(math.rad(proproll[step]-180))
				
		-- printout
		--Print(string.format("%.2f",propx[step]) .. "  " .. string.format("%.2f",propy[step]) .. "  " .. string.format("%.2f",propz[step]) .. "  " .. string.format("%.2f",proproll[step]))
		

	end
end
	--self.wndMain:SetText
	--test_win.wndMain:SetText("123")
	--self.wndMain:Close() -- hide the window
end

-- when the Cancel button is clicked
function SpiralDecorCalculator:OnCancel()
	self.wndMain:Close() -- hide the window
end

-- When y start value is entered
function SpiralDecorCalculator:y_val_start( wndHandler, wndControl, strText )
	y_val_start = strText
end

function SpiralDecorCalculator:y_val_stop( wndHandler, wndControl, strText )
	y_val_stop = strText
end

function SpiralDecorCalculator:x_val_center( wndHandler, wndControl, strText )
	x_val_center = strText
end

function SpiralDecorCalculator:z_val_center( wndHandler, wndControl, strText )
	z_val_center = strText
end

function SpiralDecorCalculator:n_steps( wndHandler, wndControl, strText )
	n_steps = strText
end

function SpiralDecorCalculator:rotation_val_degree( wndHandler, wndControl, strText )
	rotation_val_degree = strText
end

function SpiralDecorCalculator:radius_val( wndHandler, wndControl, strText )
	radius_val = strText
end

function SpiralDecorCalculator:SetSize( wndHandler, wndControl, strText )
	size_val = strText
end

function SpiralDecorCalculator:rotation_start( wndHandler, wndControl, strText )
	rotation_val_start = strText
end

function SpiralDecorCalculator:clockwise_chk( wndHandler, wndControl, eMouseButton )
	clockwise = 1
end

function SpiralDecorCalculator:clockwise_uchk( wndHandler, wndControl, eMouseButton )
	clockwise = 0
end

function SpiralDecorCalculator:prop_1( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[1],propy[1],propz[1])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[1])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_2( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[2],propy[2],propz[2])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[2])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_3( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[3],propy[3],propz[3])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[3])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_4( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[4],propy[4],propz[4])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[4])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_5( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[5],propy[5],propz[5])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[5])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_6( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[6],propy[6],propz[6])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[6])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_7( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[7],propy[7],propz[7])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[7])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_8( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[8],propy[8],propz[8])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[8])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_9( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[9],propy[9],propz[9])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[9])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_10( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[10],propy[10],propz[10])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[10])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_11( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[11],propy[11],propz[11])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[11])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_12( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[12],propy[12],propz[12])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[12])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_13( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[13],propy[13],propz[13])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[13])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_14( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[14],propy[14],propz[14])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[14])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_15( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[15],propy[15],propz[15])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[15])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_16( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[16],propy[16],propz[16])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[16])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_17( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[17],propy[17],propz[17])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[17])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_18( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[18],propy[18],propz[18])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[18])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_19( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[19],propy[19],propz[19])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[19])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_20( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[20],propy[20],propz[20])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[20])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_21( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[21],propy[21],propz[21])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[21])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_22( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[22],propy[22],propz[22])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[22])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_23( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[23],propy[23],propz[23])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[23])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_24( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[24],propy[24],propz[24])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[24])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_25( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[25],propy[25],propz[25])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[25])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_26( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[26],propy[26],propz[26])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[26])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_27( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[27],propy[27],propz[27])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[27])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_28( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[28],propy[28],propz[28])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[28])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_29( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[29],propy[29],propz[29])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[29])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_30( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[30],propy[30],propz[30])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[30])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_31( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[31],propy[31],propz[31])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[31])
	HousingLib.ScaleDecor(size_val)
end

function SpiralDecorCalculator:prop_32( wndHandler, wndControl, eMouseButton )
	HousingLib.SetDecorPosition(propx[32],propy[32],propz[32])
	HousingLib.SetDecorRotation(proppitch,propyaw,proproll[32])
	HousingLib.ScaleDecor(size_val)
end


-----------------------------------------------------------------------------------------------
-- SpiralDecorCalculator Instance
-----------------------------------------------------------------------------------------------
local SpiralDecorCalculatorInst = SpiralDecorCalculator:new()
SpiralDecorCalculatorInst:Init()
